@@ -6,13 +6,13 @@
 #define PACKAGE_BUGREPORT "am-utils@am-utils.org"
 #define HOST_CPU "powerpc"
 #define HOST_VENDOR "apple"
-#define HOST_OS "darwin7.6.0"
+#define HOST_OS "darwin7.7.0"
 #define HOST_OS_NAME "darwin7"
-#define HOST_OS_VERSION "7.6.0"
+#define HOST_OS_VERSION "7.7.0"
 #define HOST_ARCH "Power Macintosh"
 #define HOST_NAME "a-osx.fsl.cs.sunysb.edu"
 #define USER_NAME "ezk"
-#define CONFIG_DATE "Thu Jan 13 17:28:28 EST 2005"
+#define CONFIG_DATE "Wed Feb 23 22:35:29 EST 2005"
 #define PACKAGE_NAME "am-utils"
 #define PACKAGE_VERSION "6.1b5pre"
 #define PACKAGE_BUGREPORT "am-utils@am-utils.org"
@@ -30,7 +30,7 @@
 #define HAVE_STDINT_H 1
 #define HAVE_UNISTD_H 1
 #define HAVE_DLFCN_H 1
-#define HOST_HEADER_VERSION "7.6.0"
+#define HOST_HEADER_VERSION "7.7.0"
 #define YYTEXT_POINTER 1
 #define HAVE_LIBLDAP 1
 #define HAVE_LDAP_ENABLE_CACHE 1
@@ -41,7 +41,6 @@
 #define HAVE_VFORK 1
 #define HAVE_WORKING_VFORK 1
 #define HAVE_WORKING_FORK 1
-#define HAVE_WAIT3 1
 #define GETPGRP_VOID 1
 #define HAVE__SETERR_REPLY 1
 #define HAVE_BCMP 1
@@ -59,6 +58,7 @@
 #define HAVE_GETMNTINFO 1
 #define HAVE_GETPAGESIZE 1
 #define HAVE_GETTIMEOFDAY 1
+#define HAVE_HSTRERROR 1
 #define HAVE_MADVISE 1
 #define HAVE_MEMCMP 1
 #define HAVE_MEMCPY 1
